argo_float: Argo float dataset

argo_floatR Documentation

Argo float dataset

Description

Argo floats measurements.

Usage

data("argo_float")

Format

Data frame containing 274 observations on 4 variables.

lat

Latitude.

lon

Longitude.

sal

Salinity.

temp

Temperature.

Details

The floats have a pressure case made of aluminium that is about 1.3m long and about 20cm diameter. They weigh about 40kg. On the top is an antenna to communicate with the satellites that fix the float's position and receive the data. Also on the top are the temperature, salinity and pressure sensors.

Data can be obtained from Argo float website.


ngme2 documentation built on May 20, 2026, 9:10 a.m.