View source: R/complex-models.R
| bv | R Documentation |
Giving 2 sub_models, build a correlated bivariate operator based on K = D(theta, rho)
D(\theta, \rho) = \begin{pmatrix}
\cos(\theta) + \rho \sin(\theta) & -\sin(\theta) \sqrt{1+\rho^2} \\
\sin(\theta) - \rho \cos(\theta) & \cos(\theta) \sqrt{1+\rho^2}
\end{pmatrix}
bv(
mesh,
sub_models,
theta = 0,
rho = 0,
c1 = 1,
c2 = 1,
share_param = FALSE,
fix_theta = FALSE,
use_c_param = FALSE
)
mesh |
the mesh where model is defined |
sub_models |
a list of sub_models (total 2 sub_models) |
theta |
the rotation parameter (starting point should be from -pi/4 to pi/4) |
rho |
the parameter related to correlation |
c1 |
scaling factor for the first sub-model (default: 1) |
c2 |
scaling factor for the second sub-model (default: 1) |
share_param |
TRUE if share the same parameter for 2 sub_models (of same type) |
fix_theta |
TRUE if fix the theta of bv model |
use_c_param |
TRUE to estimate c1 and c2 as parameters, FALSE to fix them at specified values (default: FALSE) |
The bivariate model combines two sub-models with a rotation matrix D and optional scaling factors c1 and c2.
When use_c_param = TRUE, c1 and c2 are estimated as parameters (on log scale).
When use_c_param = FALSE (default), c1 and c2 are fixed at their specified values (both default to 1).
a ngme_operator of bivariate model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.