compare_noise_kld: Compare noise objects using Kullback-Leibler divergence

View source: R/plot.ngme.R

compare_noise_kldR Documentation

Compare noise objects using Kullback-Leibler divergence

Description

This function compares multiple noise objects by calculating the KLD of each noise against the first noise object (reference).

Usage

compare_noise_kld(x = NULL, ..., xlim = c(-10, 10), n_points = 1000)

Arguments

x

first noise object (reference)

...

additional noise objects to compare, and optional parameters

xlim

x-axis range for evaluation (default: c(-10, 10))

n_points

number of evaluation points (default: 1000)

Value

named vector of KLD values

Examples

n1 <- noise_nig(mu = 0, sigma = 1, nu = 1)
n2 <- noise_nig(mu = 0.5, sigma = 1.2, nu = 0.8)
compare_noise_kld(n1, method2 = n2)

ngme2 documentation built on May 20, 2026, 9:10 a.m.