| control_opt_batch_ci | R Documentation |
Convenience wrapper for control_opt() with defaults tailored for
Xi-style batch-means confidence intervals.
control_opt_batch_ci(
optimizer = sgd(stepsize = 0.03),
burnin = 100,
iterations = 2000,
n_batch = 20,
n_parallel_chain = 4,
alpha = 0.501,
t0 = 1,
schedule_burnin_iter = 0,
...
)
optimizer |
optimizer object, default |
burnin |
burn-in iterations before optimization. |
iterations |
optimization iterations. |
n_batch |
number of checkpoints. |
n_parallel_chain |
number of parallel chains. |
alpha |
polynomial stepsize exponent for |
t0 |
non-negative schedule offset. |
schedule_burnin_iter |
non-negative integer. Initial optimization iterations where polynomial schedule scaling is disabled. |
... |
additional arguments forwarded to |
This helper enforces trajectory-friendly defaults:
store_traj = TRUE
trend_std_conv_check = FALSE
R_hat_conv_check = FALSE
pflug_conv_check = FALSE
stepsize_control = poly_decay(alpha, t0, schedule_burnin_iter)
Any of these can still be overridden through ....
object of class control_opt.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.