get_trace_trajectories: Get trace trajectories from ngme fitting

View source: R/plot.ngme.R

get_trace_trajectoriesR Documentation

Get trace trajectories from ngme fitting

Description

Extract numerical trajectories of parameters during ngme optimization without creating plots. This function provides the underlying data used by traceplot().

Usage

get_trace_trajectories(ngme, name = "general", apply_transform = TRUE)

Arguments

ngme

ngme object

name

name of latent models, otherwise get fixed effects and measurement noise should be in names(ngme$models) or other

apply_transform

logical, whether to apply parameter transformations (default: TRUE)

Value

list containing:

trajectories

named list of trajectory matrices for each parameter

parameter_names

character vector of parameter names

transformations

list of transformation functions used

n_chains

number of chains

n_iterations

number of iterations


ngme2 documentation built on May 20, 2026, 9:10 a.m.