get_trajectories: get the trajectories of parameters of the model

View source: R/util.R

get_trajectoriesR Documentation

get the trajectories of parameters of the model

Description

Get the trajectories of the parameters of the model

Usage

get_trajectories(ngme_object, model_name)

Arguments

ngme_object

ngme object

model_name

name of the model, if NULL, return the trajectories of the parameters of the measurement noise and fixed effects

Value

a list of trajectories, each element is a matrix of trajectories (n_samples * n_trajectories)


ngme2 documentation built on May 20, 2026, 9:10 a.m.