merge_replicates: Merge model of replicates into model of 1 replicate given...

View source: R/validation.R

merge_replicatesR Documentation

Merge model of replicates into model of 1 replicate given train_idx and test_idx, the merged model contains all the information of train_idx from different replicates.

Description

Merge model of replicates into model of 1 replicate given train_idx and test_idx, the merged model contains all the information of train_idx from different replicates.

Usage

merge_replicates(ngme, train_idx, test_idx)

Arguments

ngme

a ngme object

train_idx

a vector of indices of train data

test_idx

a vector of indices of test data


ngme2 documentation built on May 20, 2026, 9:10 a.m.