ngme_cov_matrix: variance of the data or the latent field

View source: R/util.R

ngme_cov_matrixR Documentation

variance of the data or the latent field

Description

Compute the variance of the data or the latent field

Usage

ngme_cov_matrix(ngme_object, model_name = "data", replicate = 1)

Arguments

ngme_object

ngme_model

model_name

if model_name = "data", then return the covariance matrix of the data (without measurement noise) if the model_name is the name or index of the latent, then return the covariance matrix of the latent field

replicate

which replicate (default = 1)

Value

a data.frame of posterior samples (mesh_size * n_post_samples)


ngme2 documentation built on May 20, 2026, 9:10 a.m.