| ngme_make_mesh_repls | R Documentation |
Make different mesh for different replicates
ngme_make_mesh_repls(data, map, replicate, mesh_type = "regular")
data |
provide the data.frame |
map |
provide the map to make mesh, i.g. ~x+y, x and y will be extracted from data to make a 2d mesh |
replicate |
provide the replicate information, i.g. ~id |
mesh_type |
type of mesh, "regular" means use all the point from same replicate to make a mesh |
a list of mesh of length of different replicates
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.