ngme_update: Check whether a newer stable version of ngme2 is available

ngme_updateR Documentation

Check whether a newer stable version of ngme2 is available

Description

This function checks the package repository for the latest available ngme2 version. It does not install or update packages.

Usage

ngme_update()

Value

Invisibly returns a list with the local version, remote version, repository URL, and a logical update_available flag.


ngme2 documentation built on May 20, 2026, 9:10 a.m.