openmp_test: Test OpenMP availability and report the number of threads.

openmp_testR Documentation

Test OpenMP availability and report the number of threads.

Description

This function checks if OpenMP is available in the current R environment and, if so, reports the number of OpenMP threads detected. If OpenMP is not available, it reports a corresponding message. It relies on an internal or external function 'get_openmp_threads()' which is assumed to return the number of threads or 0 if unavailable.

Usage

openmp_test()

Value

Invisibly returns the detected number of OpenMP threads. A value of zero means OpenMP is not available.


ngme2 documentation built on May 20, 2026, 9:10 a.m.