plot.ngme_noise: Plot the density of one or more stationary noise objects

View source: R/plot.ngme.R

plot.ngme_noiseR Documentation

Plot the density of one or more stationary noise objects

Description

This function plots the probability density function for one or more stationary noise objects (e.g., NIG, GAL, or normal noise). Multiple noise objects can be compared on the same plot.

Usage

## S3 method for class 'ngme_noise'
plot(x = NULL, ...)

Arguments

x

An ngme_noise object (required).

...

Additional ngme_noise objects to plot, or plotting parameters such as xlim. Named arguments will be used as legend labels.

Value

A ggplot object showing the density curves for the provided noise objects.

Examples

plot(noise_nig(mu = 1, sigma = 2, nu = 1))
plot(n1 = noise_nig(mu = 0, sigma = 1, nu = 1), n2 = noise_nig(mu = 1, sigma = 1.5, nu = 0.5))

ngme2 documentation built on May 20, 2026, 9:10 a.m.