| precond_sgd | R Documentation |
Preconditioner SGD optimization
precond_sgd(stepsize = 1, numerical_eps = 1e-05)
stepsize |
stepsize for SGD |
numerical_eps |
numerical, the gap used for estimate preconditioner, default is 1e-5 |
Preconditioner SGD is using fisher information matrix as preconditioner (natural gradient descent).
a list of control variables for optimization
(used in control_opt function)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.