| print.ngme_trajectories | R Documentation |
Print method for ngme_trajectories
## S3 method for class 'ngme_trajectories'
print(x, ...)
x |
ngme_trajectories object |
... |
additional arguments |
Invisibly returns x, an ngme_trajectories object. The
method is called for its side effect of printing a summary of stored
parameter trajectory matrices, including parameter names, chain count, and
iteration count.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.