| print.noise_kld_comparison | R Documentation |
Print method for noise_kld_comparison
## S3 method for class 'noise_kld_comparison'
print(x, ...)
x |
noise_kld_comparison object |
... |
additional arguments |
Invisibly returns x, a noise_kld_comparison object. The
method is called for its side effect of printing the reference noise object,
the Kullback-Leibler divergence values for each comparison noise, and the
closest comparison.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.