| print.parameter_distance | R Documentation |
Print method for parameter_distance
## S3 method for class 'parameter_distance'
print(x, ...)
x |
parameter_distance object |
... |
additional arguments |
Invisibly returns x, a numeric vector with class
parameter_distance. The method is called for its side effect of
printing the norm type, chain summary, number of iterations, final distance,
and true parameter values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.