| stepsize_schedule | R Documentation |
Stepsize schedule
stepsize_schedule(
method = c("constant", "poly"),
alpha = 0.501,
t0 = 1,
burnin_iter = 0
)
method |
schedule type. "constant" keeps |
alpha |
polynomial exponent used when |
t0 |
non-negative offset in iteration index. |
burnin_iter |
non-negative integer. During these initial iterations, schedule scaling is fixed to 1. Afterward, polynomial decay is applied with reset local time index. |
Define an iteration-dependent stepsize schedule for use in control_opt().
This schedule is independent of stepsize_decay() and applies a direct
multiplicative scaling by iteration index:
\eta_t = \eta_0 (t + t_0)^{-\alpha}
.
a list of control variables for stepsize schedule
(used in control_opt).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.