| traceplot | R Documentation |
Trace plot of ngme fitting
traceplot(
ngme,
name = "all",
moving_window = 1,
hline = NULL,
combine = TRUE,
ncol = NULL
)
ngme |
ngme object |
name |
name of latent models, otherwise plot fixed effects and measurement noise.
Use |
moving_window |
moving window for the traceplot |
hline |
vector, add hline to each plot |
combine |
bool, if TRUE, return a single faceted ggplot; otherwise return a list of ggplot objects and print them one by one. |
ncol |
number of facet columns when |
A ggplot object when combine = TRUE; otherwise a list of ggplot
objects. The mean parameter trajectories are stored in the avg_lines
attribute of the returned object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.