| argo_float | R Documentation |
Argo floats measurements.
data("argo_float")
Data frame containing 274 observations on 4 variables.
Latitude.
Longitude.
Salinity.
Temperature.
The floats have a pressure case made of aluminium that is about 1.3m long and about 20cm diameter. They weigh about 40kg. On the top is an antenna to communicate with the satellites that fix the float's position and receive the data. Also on the top are the temperature, salinity and pressure sensors.
Data can be obtained from Argo float website.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.