| compare_noise_kld | R Documentation |
This function compares multiple noise objects by calculating the KLD of each noise against the first noise object (reference).
compare_noise_kld(x = NULL, ..., xlim = c(-10, 10), n_points = 1000)
x |
first noise object (reference) |
... |
additional noise objects to compare, and optional parameters |
xlim |
x-axis range for evaluation (default: c(-10, 10)) |
n_points |
number of evaluation points (default: 1000) |
named vector of KLD values
n1 <- noise_nig(mu = 0, sigma = 1, nu = 1)
n2 <- noise_nig(mu = 0.5, sigma = 1.2, nu = 0.8)
compare_noise_kld(n1, method2 = n2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.