| get_trace_trajectories | R Documentation |
Extract numerical trajectories of parameters during ngme optimization without creating plots. This function provides the underlying data used by traceplot().
get_trace_trajectories(ngme, name = "general", apply_transform = TRUE)
ngme |
ngme object |
name |
name of latent models, otherwise get fixed effects and measurement noise should be in names(ngme$models) or other |
apply_transform |
logical, whether to apply parameter transformations (default: TRUE) |
list containing:
named list of trajectory matrices for each parameter
character vector of parameter names
list of transformation functions used
number of chains
number of iterations
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.