| get_trajectories | R Documentation |
Get the trajectories of the parameters of the model
get_trajectories(ngme_object, model_name)
ngme_object |
ngme object |
model_name |
name of the model, if NULL, return the trajectories of the parameters of the measurement noise and fixed effects |
a list of trajectories, each element is a matrix of trajectories (n_samples * n_trajectories)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.