| igam | R Documentation |
Density, distribution function, quantile function and
random generation for the inverse-Gamma distribution
with parameters a and b.
digam(x, a, b, log = FALSE)
rigam(n, a, b)
pigam(q, a, b, lower.tail = TRUE, log.p = FALSE)
qigam(p, a, b, lower.tail = TRUE, log.p = FALSE)
x, q |
vector of quantiles. |
a, b |
parameters |
log, log.p |
logical; if |
n |
number of observations. |
lower.tail |
logical; if |
p |
vector of probabilities. |
The inverse-Gamma distribution has density given by
f(x; a, b) = \frac{b^a}{\Gamma(a)}x^{-a-1}\exp(
-\frac{b}{x}),
where x>0 and a,b>0.
digam gives the density, pigam gives the distribution function, qigam gives the quantile function, and rigam generates random deviates.
Invalid arguments will result in return value NaN, with a warning.
The length of the result is determined by n for rig.
dnig, dgig
rigam(100, a = 1, b = 1)
pigam(0.4, a = 1, b = 1)
qigam(0.8, a = 1, b = 1)
plot(function(x){digam(x, a = 1, b = 1)}, main =
"Inverse-Gamma density", ylab = "Probability density",
xlim = c(0,10))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.