This function converts a transformation name to the corresponding function. Convertion is from original scale to real scale by default. Available transformations:
exp4: \(exp(4x)\), inverse is \(log(x)/4\)exp2: \(exp(2x)\), inverse is \(log(x)/2\)tanh: Hyperbolic tangent transformation used for AR1 parameter, uses ar1_th2a and ar1_a2thidentity: Identity function, no transformationexp: \(exp(x)\), inverse is \(log(x)\)sqrt: \(sqrt(x)\), inverse is \(x^2\)square: \(x^2\), inverse is \(sqrt(x)\)log: \(log(x)\), inverse is \(exp(x)\)