| ngme | R Documentation |
ngme function performs an analysis of non-gaussian additive models.
It does the maximum likelihood estimation via stochastic gradient descent.
The prediction of unknown location can be performed by leaving the response
variable to be NA. The likelihood is specified by family.
The model estimation control can be setted in control using
control_opt() function, see ?control_opt for details.
See ngme_model_types() for available models.
ngme(
formula,
data,
family = "normal",
control_opt = NULL,
control_ngme = NULL,
group = NULL,
replicate = NULL,
start = NULL,
moving_window = 1,
prior_beta = NULL,
debug = FALSE
)
formula |
formula |
data |
a dataframe or a list providing data
(Only response variable can contain |
family |
likelihood type, same as measurement noise specification. It can be provided as:
|
control_opt |
control for optimizer. by default it is |
control_ngme |
control for ngme model. by default it is |
group |
factor, used for bivariate model, indicating which group the observation belongs to |
replicate |
factor, used for divide data into different replicates |
start |
starting ngme object (usually object from last fit) |
moving_window |
number of iterations to average the estimation |
prior_beta |
prior specification for fixed effects ('beta'), created by
|
debug |
toggle debug mode |
random effects (for different replicate) + models(fixed effects, measuremnt noise, and latent process)
ngme(
formula = Y ~ x1 + f(
x2,
model = ar1(rho = 0.5),
noise = noise_nig()
) + f(x1,
model = rw1(),
noise = noise_normal(),
),
family = noise_normal(sd = 0.5),
data = data.frame(Y = 1:5, x1 = 2:6, x2 = 3:7),
control_opt = control_opt(
estimation = FALSE
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.