| ngme2 | R Documentation |
Fits and analyzes linear latent non-Gaussian models for temporal, spatial, and space-time data. The package provides model components for autoregressive and Ornstein-Uhlenbeck processes, random walks, Matern fields based on stochastic partial differential equations, separable and non-separable space-time models, graph-based Matern models, bivariate type-G fields, and user-defined sparse operators. Latent fields and observation models can use Gaussian and non-Gaussian noise distributions, including normal inverse Gaussian, generalized asymmetric Laplace, and skew-t distributions. Functions are included for simulation, likelihood-based estimation, prediction, cross-validation, convergence diagnostics, stochastic gradient optimization, batch-means confidence intervals, and posterior-like sampling. The modeling framework is described in Bolin, Jin, Simas and Wallin (2026) "A Unified and Computationally Efficient Non-Gaussian Statistical Modeling Framework" \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2602.23987")}.
Maintainer: Xiaotian Jin xiaotian.jin@kaust.edu.sa
Authors:
David Bolin davidbolin@gmail.com [copyright holder]
Alexandre Simas alexandre.impa@gmail.com
Jonas Wallin jonas.wallin81@gmail.com
Other contributors:
Andrea V. Rocha dearocha@yahoo.com (contributed to many vignettes and examples) [contributor]
Timothy A. Davis (SuiteSparse components) [contributor, copyright holder]
Patrick R. Amestoy (SuiteSparse AMD and CAMD components) [contributor, copyright holder]
Iain S. Duff (SuiteSparse AMD and CAMD components) [contributor, copyright holder]
John K. Reid (SuiteSparse AMD-derived code) [contributor, copyright holder]
Yanqing Chen (SuiteSparse CAMD components) [contributor, copyright holder]
Sivasankaran Rajamanickam (SuiteSparse CCOLAMD components) [contributor, copyright holder]
Stefan Larimore (SuiteSparse CCOLAMD and COLAMD components) [contributor, copyright holder]
William W. Hager (SuiteSparse CHOLMOD Modify components) [contributor, copyright holder]
University of Florida (SuiteSparse CHOLMOD and CCOLAMD components) [copyright holder]
Regents of the University of Minnesota (METIS/GKlib components bundled with SuiteSparse) [copyright holder]
Free Software Foundation, Inc. (GKlib regex/getopt code bundled with SuiteSparse) [copyright holder]
Makoto Matsumoto (Mersenne Twister code bundled with SuiteSparse) [contributor, copyright holder]
Takuji Nishimura (Mersenne Twister code bundled with SuiteSparse) [contributor, copyright holder]
Alexander Chemeris (MS integer headers bundled with SuiteSparse) [contributor, copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.