| ngme_cov_matrix | R Documentation |
Compute the variance of the data or the latent field
ngme_cov_matrix(ngme_object, model_name = "data", replicate = 1)
ngme_object |
ngme_model |
model_name |
if model_name = "data", then return the covariance matrix of the data (without measurement noise) if the model_name is the name or index of the latent, then return the covariance matrix of the latent field |
replicate |
which replicate (default = 1) |
a data.frame of posterior samples (mesh_size * n_post_samples)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.