| ngme_update | R Documentation |
This function checks the package repository for the latest available ngme2 version. It does not install or update packages.
ngme_update()
Invisibly returns a list with the local version, remote version,
repository URL, and a logical update_available flag.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.