| openmp_test | R Documentation |
This function checks if OpenMP is available in the current R environment and, if so, reports the number of OpenMP threads detected. If OpenMP is not available, it reports a corresponding message. It relies on an internal or external function 'get_openmp_threads()' which is assumed to return the number of threads or 0 if unavailable.
openmp_test()
Invisibly returns the detected number of OpenMP threads. A value of zero means OpenMP is not available.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.