| plot.ngme_noise | R Documentation |
This function plots the probability density function for one or more stationary noise objects (e.g., NIG, GAL, or normal noise). Multiple noise objects can be compared on the same plot.
## S3 method for class 'ngme_noise'
plot(x = NULL, ...)
x |
An ngme_noise object (required). |
... |
Additional ngme_noise objects to plot, or plotting parameters such as |
A ggplot object showing the density curves for the provided noise objects.
plot(noise_nig(mu = 1, sigma = 2, nu = 1))
plot(n1 = noise_nig(mu = 0, sigma = 1, nu = 1), n2 = noise_nig(mu = 1, sigma = 1.5, nu = 0.5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.