Skip to contents

Stepsize schedule

Usage

stepsize_schedule(
  method = c("constant", "poly"),
  alpha = 0.501,
  t0 = 1,
  burnin_iter = 0
)

Arguments

method

schedule type. "constant" keeps \(\eta_t = \eta_0\) and "poly" uses polynomial decay.

alpha

polynomial exponent used when method = "poly". Must satisfy \(1/2 < \alpha < 1\).

t0

non-negative offset in iteration index.

burnin_iter

non-negative integer. During these initial iterations, schedule scaling is fixed to 1. Afterward, polynomial decay is applied with reset local time index.

Value

a list of control variables for stepsize schedule (used in control_opt).

Details

Define an iteration-dependent stepsize schedule for use in control_opt(). This schedule is independent of stepsize_decay() and applies a direct multiplicative scaling by iteration index: $$\eta_t = \eta_0 (t + t_0)^{-\alpha}$$.