Skip to contents

Trace plot of ngme fitting

Usage

traceplot(
  ngme,
  name = "all",
  moving_window = 1,
  hline = NULL,
  combine = TRUE,
  ncol = NULL
)

Arguments

ngme

ngme object

name

name of latent models, otherwise plot fixed effects and measurement noise. Use "all" to plot all latent models plus data parameters in one figure. should be in names(ngme$models) or other

moving_window

moving window for the traceplot

hline

vector, add hline to each plot

combine

bool, if TRUE, return a single faceted ggplot; otherwise return a list of ggplot objects and print them one by one.

ncol

number of facet columns when combine = TRUE. If NULL (default), use 2 columns for multi-parameter plots and 1 for single-parameter plots.

Value

A ggplot object when combine = TRUE; otherwise a list of ggplot objects.