Skip to contents

Trace plot of ngme fitting

Usage

traceplot(ngme, name = "all", moving_window = 1, hline = NULL, combine = TRUE)

Arguments

ngme

ngme object

name

name of latent models, otherwise plot fixed effects and measurement noise. Use "all" to plot all latent models plus data parameters in one figure. should be in names(ngme$models) or other

moving_window

moving window for the traceplot

hline

vector, add hline to each plot

combine

bool, if TRUE, plot the combination of all plots, otherwise 1 by 1

Value

the traceplot